#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_RDIVIDE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_RDIVIDE_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/rdivide.hpp>

#endif
